@@ -69,7 +69,6 @@ G_DEFINE_TYPE (PanelDesktopMenuItem, panel_desktop_menu_item, PANEL_TYPE_IMAGE_M
 
 struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
-	GSettings   *settings;
 
 	GtkRecentManager *recent_manager;
 
@@ -453,9 +452,6 @@ panel_place_menu_item_append_gtk_bookmarks (GtkWidget *menu)
 
 			keep = FALSE;
 
-			if (g_str_has_prefix (line, "x-nautilus-search:"))
-				keep = TRUE;
-
 			if (!keep) {
 				file = g_file_new_for_uri (line);
 				keep = !g_file_is_native (file) ||
@@ -547,7 +543,6 @@ panel_place_menu_item_append_gtk_bookmarks (GtkWidget *menu)
 
 		gicon = g_themed_icon_new_with_default_fallbacks (icon);
 
-		//FIXME: drag and drop will be broken for x-nautilus-search uris
 		menu_item = panel_menu_item_uri_new (bookmark->full_uri,
 						     icon, gicon,
 						     label,
@@ -1141,12 +1136,6 @@ panel_place_menu_item_recreate_menu (GtkWidget *widget)
 	}
 }
 
-static void
-panel_place_menu_item_key_changed (GSettings *settings, const gchar *key, GtkWidget *place_item)
-{
-	panel_place_menu_item_recreate_menu (place_item);
-}
-
 static void
 panel_place_menu_item_gtk_bookmarks_changed (GFileMonitor *handle,
 					     GFile        *file,
@@ -1207,8 +1196,6 @@ panel_place_menu_item_dispose (GObject *object)
 {
   PanelPlaceMenuItem *menuitem = (PanelPlaceMenuItem *) object;
 
-  g_clear_object (&menuitem->priv->settings);
-
   if (menuitem->priv->bookmarks_monitor != NULL)
     {
       g_file_monitor_cancel (menuitem->priv->bookmarks_monitor);
@@ -1272,17 +1259,9 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 	GFile *bookmark;
 	char  *bookmarks_filename;
 	GError *error;
-	GSettings *settings;
 
 	menuitem->priv = PANEL_PLACE_MENU_ITEM_GET_PRIVATE (menuitem);
 
-	settings = g_settings_new (GNOME_NAUTILUS_DESKTOP_SCHEMA);
-
-	menuitem->priv->settings = settings;
-
-	g_signal_connect (settings, "changed::" GNOME_NAUTILUS_DESKTOP_HOME_ICON_NAME_KEY,
-	                  G_CALLBACK (panel_place_menu_item_key_changed), menuitem);
-
 	menuitem->priv->recent_manager = gtk_recent_manager_get_default ();
 
 	bookmarks_filename = panel_gtk_get_bookmark_file ();
