@@ -719,18 +719,8 @@ panel_util_get_file_display_for_common_files (GFile *file)
 
 	compare = g_file_new_for_path (g_get_home_dir ());
 	if (g_file_equal (file, compare)) {
-		GSettings *settings = g_settings_new (GNOME_NAUTILUS_DESKTOP_SCHEMA);
-		char *home_foler_name = g_settings_get_string (settings, GNOME_NAUTILUS_DESKTOP_HOME_ICON_NAME_KEY);
-
 		g_object_unref (compare);
-		g_object_unref (settings);
-
-		if (PANEL_GLIB_STR_EMPTY (home_foler_name)) {
-			g_free (home_foler_name);
-			return g_strdup (_("Home Folder"));
-		} else {
-			return home_foler_name;
-		}
+		return g_strdup (_("Home"));
 	}
 	g_object_unref (compare);
 
@@ -896,7 +886,6 @@ panel_util_get_label_for_uri (const char *text_uri)
 	char  *root_display;
 
 	/* Here's what we do:
-	 *  + x-nautilus-search: URI
 	 *  + check if the URI is a mount
 	 *  + if file: URI:
 	 *   - check for known file: URI
@@ -910,10 +899,6 @@ panel_util_get_label_for_uri (const char *text_uri)
 
 	label = NULL;
 
-	//FIXME: see nautilus_query_to_readable_string() to have a nice name
-	if (g_str_has_prefix (text_uri, "x-nautilus-search:"))
-		return g_strdup (_("Search"));
-
 	file = g_file_new_for_uri (text_uri);
 
 	label = panel_util_get_file_display_name_if_mount (file);
@@ -984,7 +969,6 @@ panel_util_get_icon_for_uri (const char *text_uri)
 
 	/* Here's what we do:
 	 *  + check for known file: URI
-	 *  + x-nautilus-search: URI
 	 *  + override burn: URI icon
 	 *  + check if the URI is a mount
 	 *  + override trash: URI icon for subfolders
@@ -998,8 +982,6 @@ panel_util_get_icon_for_uri (const char *text_uri)
 	if (icon)
 		return g_strdup (icon);
 
-	if (g_str_has_prefix (text_uri, "x-nautilus-search:"))
-		return g_strdup (PANEL_ICON_SAVED_SEARCH);
 	/* gvfs doesn't give us a nice icon, so overriding */
 	if (g_str_has_prefix (text_uri, "burn:"))
 		return g_strdup (PANEL_ICON_BURNER);
