@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Alberts Muktupāvels
+ * Copyright (C) 2016-2018 Alberts Muktupāvels
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -18,18 +18,22 @@
 #ifndef GP_APPLET_INFO_PRIVATE_H
 #define GP_APPLET_INFO_PRIVATE_H
 
-#include "libgnome-panel/gp-applet-info.h"
+#include <libgnome-panel/gp-applet-info.h>
+
+G_BEGIN_DECLS
 
 struct _GpAppletInfo
 {
-  gchar    *name;
-  gchar    *description;
-  gchar    *icon_name;
+  GpGetAppletTypeFunc     get_applet_type_func;
 
-  gchar    *help_uri;
-  gboolean  has_about_dialog;
+  gchar                  *name;
+  gchar                  *description;
+  gchar                  *icon_name;
 
-  gchar    *backends;
+  gchar                  *help_uri;
+  GpSetupAboutDialogFunc  about_dialog_func;
+
+  gchar                  *backends;
 };
 
 void gp_applet_info_free (GpAppletInfo *info);
