@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2001 Sun Microsystems, Inc.
  * Copyright (c) 2010 Carlos Garcia Campos
- * Copyright (C) 2016 Alberts Muktupāvels
+ * Copyright (C) 2016-2018 Alberts Muktupāvels
  *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -62,7 +62,7 @@ typedef struct
 
   gchar              *id;
   gchar              *settings_path;
-  gchar              *translation_domain;
+  gchar              *gettext_domain;
   gboolean            locked_down;
   GtkOrientation      orientation;
   GtkPositionType     position;
@@ -71,6 +71,13 @@ typedef struct
   GpSizeHints        *size_hints;
 
   guint               size_hints_idle;
+
+  GSettings          *general_settings;
+
+  gboolean            enable_tooltips;
+
+  guint               panel_icon_size;
+  guint               menu_icon_size;
 } GpAppletPrivate;
 
 enum
@@ -79,11 +86,16 @@ enum
 
   PROP_ID,
   PROP_SETTINGS_PATH,
-  PROP_TRANSLATION_DOMAIN,
+  PROP_GETTEXT_DOMAIN,
   PROP_LOCKED_DOWN,
   PROP_ORIENTATION,
   PROP_POSITION,
 
+  PROP_ENABLE_TOOLTIPS,
+
+  PROP_PANEL_ICON_SIZE,
+  PROP_MENU_ICON_SIZE,
+
   LAST_PROP
 };
 
@@ -91,7 +103,6 @@ static GParamSpec *properties[LAST_PROP] = { NULL };
 
 enum
 {
-  LOCKED_DOWN_CHANGED,
   PLACEMENT_CHANGED,
 
   FLAGS_CHANGED,
@@ -104,6 +115,113 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GpApplet, gp_applet, GTK_TYPE_EVENT_BOX)
 
+static void
+update_enable_tooltips (GpApplet *applet)
+{
+  GpAppletPrivate *priv;
+  gboolean enable_tooltips;
+
+  priv = gp_applet_get_instance_private (applet);
+  enable_tooltips = g_settings_get_boolean (priv->general_settings,
+                                            "enable-tooltips");
+
+  if (priv->enable_tooltips == enable_tooltips)
+    return;
+
+  priv->enable_tooltips = enable_tooltips;
+
+  g_object_notify_by_pspec (G_OBJECT (applet),
+                            properties[PROP_ENABLE_TOOLTIPS]);
+}
+
+static void
+update_menu_icon_size (GpApplet *applet)
+{
+  GpAppletPrivate *priv;
+  guint menu_icon_size;
+
+  priv = gp_applet_get_instance_private (applet);
+  menu_icon_size = g_settings_get_enum (priv->general_settings,
+                                        "menu-icon-size");
+
+  if (priv->menu_icon_size == menu_icon_size)
+    return;
+
+  priv->menu_icon_size = menu_icon_size;
+
+  g_object_notify_by_pspec (G_OBJECT (applet),
+                            properties[PROP_MENU_ICON_SIZE]);
+}
+
+static void
+update_panel_icon_size (GpApplet *applet)
+{
+  GpAppletPrivate *priv;
+  guint panel_max_icon_size;
+  GtkAllocation allocation;
+  guint panel_size;
+  guint spacing;
+  guint panel_icon_size;
+
+  priv = gp_applet_get_instance_private (applet);
+  panel_max_icon_size = g_settings_get_enum (priv->general_settings,
+                                             "panel-max-icon-size");
+
+  gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
+
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+    panel_size = allocation.height;
+  else if (priv->orientation == GTK_ORIENTATION_VERTICAL)
+    panel_size = allocation.width;
+  else
+    g_assert_not_reached ();
+
+  spacing = 4;
+
+  if (panel_size <= panel_max_icon_size + spacing)
+    {
+      if (panel_size < 22 + spacing)
+        panel_icon_size = 16;
+      else if (panel_size < 24 + spacing)
+        panel_icon_size = 22;
+      else if (panel_size < 32 + spacing)
+        panel_icon_size = 24;
+      else if (panel_size < 48 + spacing)
+        panel_icon_size = 32;
+      else if (panel_size < 64 + spacing)
+        panel_icon_size = 48;
+      else
+        panel_icon_size = 64;
+    }
+  else
+    {
+      panel_icon_size = panel_max_icon_size;
+    }
+
+  if (priv->panel_icon_size == panel_icon_size)
+    return;
+
+  priv->panel_icon_size = panel_icon_size;
+
+  g_object_notify_by_pspec (G_OBJECT (applet),
+                            properties[PROP_PANEL_ICON_SIZE]);
+}
+
+static void
+general_settings_changed_cb (GSettings   *settings,
+                             const gchar *key,
+                             GpApplet    *applet)
+{
+  if (key == NULL || g_strcmp0 (key, "enable-tooltips") == 0)
+    update_enable_tooltips (applet);
+
+  if (key == NULL || g_strcmp0 (key, "menu-icon-size") == 0)
+    update_menu_icon_size (applet);
+
+  if (key == NULL || g_strcmp0 (key, "panel-max-icon-size") == 0)
+    update_panel_icon_size (applet);
+}
+
 static gboolean
 emit_size_hints_changed_cb (gpointer user_data)
 {
@@ -182,7 +300,7 @@ gp_applet_constructed (GObject *object)
   applet = GP_APPLET (object);
   priv = gp_applet_get_instance_private (applet);
 
-  gtk_builder_set_translation_domain (priv->builder, priv->translation_domain);
+  gtk_builder_set_translation_domain (priv->builder, priv->gettext_domain);
 
   group = G_ACTION_GROUP (priv->action_group);
   gtk_widget_insert_action_group (GTK_WIDGET (applet), priv->id, group);
@@ -209,6 +327,8 @@ gp_applet_dispose (GObject *object)
       priv->size_hints_idle = 0;
     }
 
+  g_clear_object (&priv->general_settings);
+
   G_OBJECT_CLASS (gp_applet_parent_class)->dispose (object);
 }
 
@@ -223,7 +343,7 @@ gp_applet_finalize (GObject *object)
 
   g_clear_pointer (&priv->id, g_free);
   g_clear_pointer (&priv->settings_path, g_free);
-  g_clear_pointer (&priv->translation_domain, g_free);
+  g_clear_pointer (&priv->gettext_domain, g_free);
   g_clear_pointer (&priv->size_hints, gp_size_hints_free);
 
   G_OBJECT_CLASS (gp_applet_parent_class)->finalize (object);
@@ -251,8 +371,8 @@ gp_applet_get_property (GObject    *object,
         g_value_set_string (value, priv->settings_path);
         break;
 
-      case PROP_TRANSLATION_DOMAIN:
-        g_value_set_string (value, priv->translation_domain);
+      case PROP_GETTEXT_DOMAIN:
+        g_value_set_string (value, priv->gettext_domain);
         break;
 
       case PROP_LOCKED_DOWN:
@@ -267,6 +387,18 @@ gp_applet_get_property (GObject    *object,
         g_value_set_enum (value, priv->position);
         break;
 
+      case PROP_ENABLE_TOOLTIPS:
+        g_value_set_boolean (value, priv->enable_tooltips);
+        break;
+
+      case PROP_PANEL_ICON_SIZE:
+        g_value_set_uint (value, priv->panel_icon_size);
+        break;
+
+      case PROP_MENU_ICON_SIZE:
+        g_value_set_uint (value, priv->menu_icon_size);
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -297,9 +429,9 @@ gp_applet_set_property (GObject      *object,
         priv->settings_path = g_value_dup_string (value);
         break;
 
-      case PROP_TRANSLATION_DOMAIN:
-        g_assert (priv->translation_domain == NULL);
-        priv->translation_domain = g_value_dup_string (value);
+      case PROP_GETTEXT_DOMAIN:
+        g_assert (priv->gettext_domain == NULL);
+        priv->gettext_domain = g_value_dup_string (value);
         break;
 
       case PROP_LOCKED_DOWN:
@@ -314,6 +446,15 @@ gp_applet_set_property (GObject      *object,
         gp_applet_set_position (applet, g_value_get_enum (value));
         break;
 
+      case PROP_ENABLE_TOOLTIPS:
+        break;
+
+      case PROP_PANEL_ICON_SIZE:
+        break;
+
+      case PROP_MENU_ICON_SIZE:
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -394,6 +535,19 @@ gp_applet_get_request_mode (GtkWidget *widget)
   return GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT;
 }
 
+static void
+gp_applet_size_allocate (GtkWidget     *widget,
+                         GtkAllocation *allocation)
+{
+  GpApplet *applet;
+
+  applet = GP_APPLET (widget);
+
+  GTK_WIDGET_CLASS (gp_applet_parent_class)->size_allocate (widget, allocation);
+
+  update_panel_icon_size (applet);
+}
+
 static void
 install_properties (GObjectClass *object_class)
 {
@@ -419,13 +573,13 @@ install_properties (GObjectClass *object_class)
                          G_PARAM_STATIC_STRINGS);
 
   /**
-   * GpApplet:translation-domain:
+   * GpApplet:gettext-domain:
    *
-   * The translation domain.
+   * The gettext domain.
    */
-  properties[PROP_TRANSLATION_DOMAIN] =
-    g_param_spec_string ("translation-domain", "Translation Domain",
-                         "Translation Domain", NULL,
+  properties[PROP_GETTEXT_DOMAIN] =
+    g_param_spec_string ("gettext-domain", "Gettext Domain",
+                         "Gettext Domain", NULL,
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
                          G_PARAM_STATIC_STRINGS);
 
@@ -437,7 +591,7 @@ install_properties (GObjectClass *object_class)
   properties[PROP_LOCKED_DOWN] =
     g_param_spec_boolean ("locked-down", "Locked Down", "Locked Down",
                           FALSE,
-                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
+                          G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
                           G_PARAM_STATIC_STRINGS);
 
   /**
@@ -448,7 +602,7 @@ install_properties (GObjectClass *object_class)
   properties[PROP_ORIENTATION] =
     g_param_spec_enum ("orientation", "Orientation", "Orientation",
                        GTK_TYPE_ORIENTATION, GTK_ORIENTATION_HORIZONTAL,
-                       G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
+                       G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
                        G_PARAM_STATIC_STRINGS);
 
   /**
@@ -459,7 +613,40 @@ install_properties (GObjectClass *object_class)
   properties[PROP_POSITION] =
     g_param_spec_enum ("position", "Position", "Position",
                        GTK_TYPE_POSITION_TYPE, GTK_POS_TOP,
-                       G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
+                       G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
+                       G_PARAM_STATIC_STRINGS);
+
+  /**
+   * GpApplet:enable-tooltips:
+   *
+   * Whether the applet should show tooltips.
+   */
+  properties[PROP_ENABLE_TOOLTIPS] =
+    g_param_spec_boolean ("enable-tooltips", "Enable Tooltips", "Enable Tooltips",
+                          TRUE,
+                          G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
+                          G_PARAM_STATIC_STRINGS);
+
+  /**
+   * GpApplet:panel-icon-size:
+   *
+   * The size of icons in panels.
+   */
+  properties[PROP_PANEL_ICON_SIZE] =
+    g_param_spec_uint ("panel-icon-size", "Panel Icon Size", "Panel Icon Size",
+                       16, 64, 16,
+                       G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
+                       G_PARAM_STATIC_STRINGS);
+
+  /**
+   * GpApplet:menu-icon-size:
+   *
+   * The size of icons in panels.
+   */
+  properties[PROP_MENU_ICON_SIZE] =
+    g_param_spec_uint ("menu-icon-size", "Menu Icon Size", "Menu Icon Size",
+                       16, 24, 16,
+                       G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY |
                        G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, properties);
@@ -468,19 +655,6 @@ install_properties (GObjectClass *object_class)
 static void
 install_signals (void)
 {
-  /**
-   * GpApplet::locked-down-changed:
-   * @applet: the object on which the signal is emitted
-   * @locked_down: the new locked down value
-   *
-   * Signal is emmited when the locked down property of applet has
-   * changed.
-   */
-  signals[LOCKED_DOWN_CHANGED] =
-    g_signal_new ("locked-down-changed", GP_TYPE_APPLET, G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GpAppletClass, locked_down_changed),
-                  NULL, NULL, NULL, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-
   /**
    * GpApplet::placement-changed:
    * @applet: the object on which the signal is emitted
@@ -538,6 +712,7 @@ gp_applet_class_init (GpAppletClass *applet_class)
   widget_class->draw = gp_applet_draw;
   widget_class->focus = gp_applet_focus;
   widget_class->get_request_mode = gp_applet_get_request_mode;
+  widget_class->size_allocate = gp_applet_size_allocate;
 
   install_properties (object_class);
   install_signals ();
@@ -554,6 +729,13 @@ gp_applet_init (GpApplet *applet)
 
   priv->builder = gtk_builder_new ();
   priv->action_group = g_simple_action_group_new ();
+
+  priv->general_settings = g_settings_new ("org.gnome.gnome-panel.general");
+
+  g_signal_connect (priv->general_settings, "changed",
+                    G_CALLBACK (general_settings_changed_cb), applet);
+
+  general_settings_changed_cb (priv->general_settings, NULL, applet);
 }
 
 /**
@@ -589,7 +771,7 @@ gp_applet_set_locked_down (GpApplet *applet,
 
   priv->locked_down = locked_down;
 
-  g_signal_emit (applet, signals[LOCKED_DOWN_CHANGED], 0, locked_down);
+  g_object_notify_by_pspec (G_OBJECT (applet), properties[PROP_LOCKED_DOWN]);
 }
 
 /**
@@ -626,6 +808,8 @@ gp_applet_set_orientation (GpApplet       *applet,
                  orientation, priv->position);
 
   priv->orientation = orientation;
+
+  g_object_notify_by_pspec (G_OBJECT (applet), properties[PROP_ORIENTATION]);
 }
 
 /**
@@ -662,6 +846,8 @@ gp_applet_set_position (GpApplet        *applet,
                  priv->orientation, position);
 
   priv->position = position;
+
+  g_object_notify_by_pspec (G_OBJECT (applet), properties[PROP_POSITION]);
 }
 
 /**
@@ -1032,20 +1218,39 @@ gp_applet_get_menu (GpApplet *applet)
 }
 
 /**
- * gp_applet_add_text_class:
+ * gp_applet_get_panel_icon_size:
  * @applet: a #GpApplet
- * @widget: a #GtkWidget
  *
- * Use this function to add css class to widgets that are visible on panel
- * and shows text.
+ * Returns the panel icon size.
+ *
+ * Returns: the panel icon size.
  */
-void
-gp_applet_add_text_class (GpApplet  *applet,
-                          GtkWidget *widget)
+guint
+gp_applet_get_panel_icon_size (GpApplet *applet)
 {
-  GtkStyleContext *context;
+  GpAppletPrivate *priv;
 
-  context = gtk_widget_get_style_context (widget);
+  g_return_val_if_fail (GP_IS_APPLET (applet), 16);
+  priv = gp_applet_get_instance_private (applet);
 
-  gtk_style_context_add_class (context, "gp-text-color");
+  return priv->panel_icon_size;
+}
+
+/**
+ * gp_applet_get_menu_icon_size:
+ * @applet: a #GpApplet
+ *
+ * Returns the menu icon size.
+ *
+ * Returns: the menu icon size.
+ */
+guint
+gp_applet_get_menu_icon_size (GpApplet *applet)
+{
+  GpAppletPrivate *priv;
+
+  g_return_val_if_fail (GP_IS_APPLET (applet), 16);
+  priv = gp_applet_get_instance_private (applet);
+
+  return priv->menu_icon_size;
 }
