@@ -50,6 +50,7 @@
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-wall-clock.h>
 
+#include <libgnome-panel/gp-utils.h>
 #include <libgweather/gweather.h>
 
 #include "clock-applet.h"
@@ -743,7 +744,7 @@ create_main_clock_label (ClockApplet *cd)
 			  G_CALLBACK (clock_update_text_gravity),
 			  NULL);
 
-        gp_applet_add_text_class (GP_APPLET (cd), label);
+        gp_add_text_color_class (label);
 
         return label;
 }
@@ -837,6 +838,8 @@ create_clock_widget (ClockApplet *cd)
         g_settings_bind (cd->applet_settings, "show-temperature", cd->panel_temperature_label, "visible",
                          G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_NO_SENSITIVITY);
 
+        gp_add_text_color_class (cd->panel_temperature_label);
+
         /* Main label for time display */
 	cd->clockw = create_main_clock_label (cd);
         gtk_box_pack_start (GTK_BOX (cd->main_obox), cd->clockw, FALSE, FALSE, 0);
@@ -1352,11 +1355,13 @@ run_prefs_edit_save (GtkButton   *button,
 }
 
 static void
-update_coords_helper (gfloat value, GtkWidget *entry, GtkWidget *combo)
+update_coords_helper (gdouble    value,
+                      GtkWidget *entry,
+                      GtkWidget *combo)
 {
         gchar *tmp;
 
-        tmp = g_strdup_printf ("%f", fabsf (value));
+        tmp = g_strdup_printf ("%f", fabs (value));
         gtk_entry_set_text (GTK_ENTRY (entry), tmp);
         g_free (tmp);
 
@@ -1370,8 +1375,8 @@ update_coords_helper (gfloat value, GtkWidget *entry, GtkWidget *combo)
 static void
 update_coords (ClockApplet *cd,
                gboolean     valid,
-               gfloat       lat,
-               gfloat       lon)
+               gdouble      lat,
+               gdouble      lon)
 {
         GtkWidget *lat_entry = _clock_get_widget (cd, "edit-location-latitude-entry");
         GtkWidget *lon_entry = _clock_get_widget (cd, "edit-location-longitude-entry");
@@ -1510,12 +1515,74 @@ prefs_hide_event (GtkWidget   *widget,
         return TRUE;
 }
 
+static void
+clock_utils_display_help (GtkWidget   *widget,
+                          const gchar *doc_id,
+                          const gchar *link_id,
+                          GtkWindow   *parent)
+{
+	GError *error = NULL;
+	char   *uri;
+
+	if (link_id)
+		uri = g_strdup_printf ("help:%s/%s", doc_id, link_id);
+	else
+		uri = g_strdup_printf ("help:%s", doc_id);
+
+	gtk_show_uri_on_window (parent, uri, gtk_get_current_event_time (), &error);
+	g_free (uri);
+
+	if (error &&
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+		g_error_free (error);
+	else if (error) {
+		GtkWidget *dialog;
+		char      *primary;
+
+		primary = g_markup_printf_escaped (
+				_("Could not display help document '%s'"),
+				doc_id);
+		dialog = gtk_message_dialog_new (
+				parent,
+				GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CLOSE,
+				"%s", primary);
+
+		gtk_message_dialog_format_secondary_text (
+					GTK_MESSAGE_DIALOG (dialog),
+					"%s", error->message);
+
+		g_error_free (error);
+		g_free (primary);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), CLOCK_ICON);
+		gtk_window_set_screen (GTK_WINDOW (dialog),
+				       gtk_widget_get_screen (widget));
+
+		if (parent == NULL) {
+			/* we have no parent window */
+			gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog),
+							  FALSE);
+			gtk_window_set_title (GTK_WINDOW (dialog),
+					      _("Error displaying help document"));
+		}
+
+		gtk_widget_show (dialog);
+	}
+}
+
 static void
 prefs_help (GtkWidget   *widget,
             ClockApplet *cd)
 {
 	clock_utils_display_help (cd->prefs_window,
-				  "clock", "clock-settings");
+				  "clock", "clock-settings",
+				  GTK_WINDOW (cd->prefs_window));
 }
 
 static void
@@ -1603,7 +1670,7 @@ edit_tree_row (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoint
 
         fill_timezone_combo_from_location (cd, loc);
 
-        tmp = g_strdup_printf ("%f", fabsf(lat));
+        tmp = g_strdup_printf ("%f", fabs (lat));
         gtk_entry_set_text (GTK_ENTRY (lat_entry), tmp);
         g_free (tmp);
 
@@ -1613,7 +1680,7 @@ edit_tree_row (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpoint
                 gtk_combo_box_set_active (GTK_COMBO_BOX (lat_combo), 1);
         }
 
-        tmp = g_strdup_printf ("%f", fabsf(lon));
+        tmp = g_strdup_printf ("%f", fabs (lon));
         gtk_entry_set_text (GTK_ENTRY (lon_entry), tmp);
         g_free (tmp);
 
